# -*- coding: utf-8 -*-

# about.py
# This file is part of Qarte
#    
# Author : Vincent Vande Vyvre <vincent.vandevyvre@swing.be>
# Copyright: 2011-2013 Vincent Vande Vyvre
# Licence: GPL3
# Home page : https://launchpad.net/qarte
#
# About Qarte dialog box

import os
import subprocess
import sys
import platform

from PyQt4.QtCore import Qt, QT_VERSION_STR, PYQT_VERSION_STR
from PyQt4.QtGui import QApplication, QDialog, QGridLayout, QVBoxLayout,\
                        QHBoxLayout, QSizePolicy, QIcon, QPixmap, QSpacerItem,\
                        QPlainTextEdit, QLabel, QPushButton,\
                        QTextCharFormat, QFont, QWidget

from sip import SIP_VERSION_STR


class VersionsInfos(object):
    def __init__(self, v):
        """Show a dialog box with version infos
        
        Args:
        v -- version of Qarte
        """
        VERSION__STR = v
        PY_VERSION = sys.version.split()[0]
        PLATFORM = platform.platform()

        rep = subprocess.Popen(["rtmpdump"], shell=True, 
                                universal_newlines=True,
                                stdout = subprocess.PIPE, 
                                stderr=subprocess.STDOUT)
        line = rep.stdout.readline()
        RTMPDUMP_VERSION = line.split()[1]

        versions = {u"platform": PLATFORM,
                    u"Qarte": VERSION__STR,
                    u"python": PY_VERSION,
                    u"qt": QT_VERSION_STR,
                    u"pyqt": PYQT_VERSION_STR,
                    u"sip": SIP_VERSION_STR,
                    u"RTMPDump": RTMPDUMP_VERSION}

        font = QFont("Mono", 10)
        c_form = QTextCharFormat()
        c_form.setFont(font)
        font1 = QFont("sans", 10)
        font1.setWeight(56)
        c_form1 = QTextCharFormat()
        c_form1.setFont(font1)
        VersionsDialog = QDialog()
        ui = Ui_VersionsDialog()
        ui.setupUi(VersionsDialog, versions)
        ui.platform_lbl.setText(PLATFORM)
        VersionsDialog.show()

        l = 25 - len(VERSION__STR)
        ui.editor.setCurrentCharFormat(c_form1)
        ui.editor.appendPlainText("Qarte")
        txt = "\t" + " " * l + VERSION__STR
        ui.editor.setCurrentCharFormat(c_form)
        ui.editor.insertPlainText(txt)

        l = 25 - len(PY_VERSION)
        ui.editor.setCurrentCharFormat(c_form1)
        ui.editor.appendPlainText("Python")
        txt = "\t" + " " * l + PY_VERSION
        ui.editor.setCurrentCharFormat(c_form)
        ui.editor.insertPlainText(txt)

        l = 25 - len(QT_VERSION_STR)
        ui.editor.setCurrentCharFormat(c_form1)
        ui.editor.appendPlainText("Qt")
        txt = "\t" + " " * l + QT_VERSION_STR
        ui.editor.setCurrentCharFormat(c_form)
        ui.editor.insertPlainText(txt)

        l = 25 - len(PYQT_VERSION_STR)
        ui.editor.setCurrentCharFormat(c_form1)
        ui.editor.appendPlainText("PyQt")
        txt = "\t" + " " * l + PYQT_VERSION_STR
        ui.editor.setCurrentCharFormat(c_form)
        ui.editor.insertPlainText(txt)

        l = 25 - len(SIP_VERSION_STR)
        ui.editor.setCurrentCharFormat(c_form1)
        ui.editor.appendPlainText("Sip")
        txt = "\t" + " " * l + SIP_VERSION_STR
        ui.editor.setCurrentCharFormat(c_form)
        ui.editor.insertPlainText(txt)

        l = 15 - len(RTMPDUMP_VERSION)
        ui.editor.setCurrentCharFormat(c_form1)
        ui.editor.appendPlainText("RTMPDump")
        txt = "\t" + " " * l + RTMPDUMP_VERSION
        ui.editor.setCurrentCharFormat(c_form)
        ui.editor.insertPlainText(txt)

        VersionsDialog.exec_()


class Ui_VersionsDialog(object):
    def setupUi(self, VersionsDialog, vers):
        VersionsDialog.setObjectName("VersionsDialog")
        VersionsDialog.resize(380, 380)
        VersionsDialog.setWindowTitle("About Qarte")
        self.gridLayout = QGridLayout(VersionsDialog)
        self.gridLayout.setMargin(0)
        self.widget = QWidget(VersionsDialog)
        self.widget.setStyleSheet("""background: qlineargradient(
                                        x1: 0.3, y1: 0.3, x2: 1, y2: 1,
                                        stop: 0 #FFFFFF, stop: 1 #BBBBBB)""")
        self.verticalLayout_3 = QVBoxLayout(self.widget)
        self.verticalLayout_3.setMargin(6)
        #self.verticalLayout_3 = QVBoxLayout()
        self.Title_lbl = QLabel(self.widget)
        font = QFont()
        font.setFamily("DejaVu Sans")
        font.setPointSize(14)
        self.Title_lbl.setFont(font)
        self.Title_lbl.setText("<b>Qarte</b>")
        self.Title_lbl.setAlignment(Qt.AlignCenter)
        self.verticalLayout_3.addWidget(self.Title_lbl)
        self.author_lbl = QLabel(self.widget)
        self.author_lbl.setText("Author: Vincent Vande Vyvre")
        self.author_lbl.setAlignment(Qt.AlignCenter)
        self.verticalLayout_3.addWidget(self.author_lbl)
        self.licence_lbl = QLabel(self.widget)
        self.licence_lbl.setText("licence: GPL-3")
        self.licence_lbl.setAlignment(Qt.AlignCenter)
        self.verticalLayout_3.addWidget(self.licence_lbl)
        self.home_lbl = QLabel(self.widget)
        self.home_lbl.setText("Home page:")
        self.home_lbl.setAlignment(Qt.AlignCenter)
        self.verticalLayout_3.addWidget(self.home_lbl)
        self.home_lbl2 = QLabel(self.widget)
        self.home_lbl2.setText("https://launchpad.net/qarte")
        self.home_lbl2.setAlignment(Qt.AlignCenter)
        self.verticalLayout_3.addWidget(self.home_lbl2)
        self.install_lbl = QLabel(self.widget)
        self.install_lbl.setText("Installed on:")
        self.install_lbl.setAlignment(Qt.AlignCenter)
        self.verticalLayout_3.addWidget(self.install_lbl)
        self.platform_lbl = QLabel(self.widget)
        self.platform_lbl.setText("")
        self.platform_lbl.setAlignment(Qt.AlignCenter)
        self.verticalLayout_3.addWidget(self.platform_lbl)
        self.vers_lbl = QLabel(self.widget)
        self.vers_lbl.setText("Versions:")
        self.verticalLayout_3.addWidget(self.vers_lbl)
        self.editor = QPlainTextEdit(self.widget)
        self.editor.setTextInteractionFlags(Qt.TextSelectableByKeyboard
                                        |Qt.TextSelectableByMouse)
        self.verticalLayout_3.addWidget(self.editor)
        self.horizontalLayout = QHBoxLayout()
        spacerItem1 = QSpacerItem(40, 20, QSizePolicy.Expanding,
                                        QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.copy_btn = QPushButton(self.widget)
        self.copy_btn.setText("Copy all")
        icon = QIcon()
        icon.addPixmap(QPixmap("medias/copy.png"), QIcon.Normal,
                                         QIcon.Off)
        self.copy_btn.setIcon(icon)
        self.horizontalLayout.addWidget(self.copy_btn)
        self.close_btn = QPushButton(self.widget)
        self.close_btn.setText("Close")
        icon1 = QIcon()
        icon1.addPixmap(QPixmap("medias/close.png"), QIcon.Normal,
                                        QIcon.Off)
        self.close_btn.setIcon(icon1)
        self.horizontalLayout.addWidget(self.close_btn)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        #self.verticalLayout_4.addLayout(self.verticalLayout_3)
        self.gridLayout.addWidget(self.widget, 0, 0, 1, 1)

        self.copy_btn.clicked.connect(self.copy_all)
        self.close_btn.clicked.connect(VersionsDialog.accept)
        self.clip_board = QApplication.clipboard()
        self.versions = vers

    def copy_all(self):
        """Copy all versions nummers into the clipboard.

        The method copy() of QPlainTextEdit don't save the formatting of the
        text, so we re-create it.
        """
        txt = """Qarte\t\t%(Qarte)s\nPlatform\t%(platform)s\nQt\t\t\t%(qt)s
Python\t\t%(python)s\nPyQt\t\t%(pyqt)s\nSip\t\t\t%(sip)s
RTMPDump\t%(RTMPDump)s""" % self.versions
        self.clip_board.setText(txt)
